@@ -28,7 +28,7 @@ class Graph:
                 self.topologicalSortUtil(i, visited, stack)
         return(stack[::-1]) 
  
-def generate_file(graph, colab=False):
+def generate_file(graph, colab=False,target_column,task_type):
     g = Graph(len(graph['nodes']))
     map = {}
     j=0
@@ -65,39 +65,13 @@ def generate_file(graph, colab=False):
                         f.write(essentials_generate(node))
                         f.write("\n")
                     elif steps_list[i] == 'evaluate_model':
-                        f.write("metrics = huble.util.evaluate_model(model=Model, test_dataset=test_dataset, 'classification' )")
+                        f.write(f"metrics = huble.util.evaluate_model(model=Model, test_dataset=test_dataset, target_column= '{target_column}, task_type='{task_type}' )")
                         f.write("\n")
                     elif steps_list[i] == 'primary_dataset':
-                        f.write(f"data=huble.util.load_dataset({node['data']['url']})")
+                        f.write(f"data=huble.util.load_dataset('{node['data']['url']}')")
                         f.write("\n")
 
 
 
 
 
-
-
-
-# def generate_file(url,graph,colab=False):
-
-#     preprocess_template = preprocess_generate(graph)
-#     train_template = temp_logistic_regression()
-#     #output_template = preprocess_template + train_template
-#     with open("/content/output.py", "w") as f:
-#         f.write("import huble\n")
-#         f.write("from sklearn.model_selection import train_test_split\n")
-#         f.write(f"data=huble.util.load_dataset({url})")
-#         f.write(preprocess_template)
-#         f.write("\nX = data.drop(columns = ['survived'],axis = 1)\n")
-#         f.write("y = data['survived']\n")
-#         f.write("X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=42)\n")
-#         f.write(train_template)
-#         f.write("\nmodel.fit(X,y)\n")
-#         f.write("y_pred = model.predict(X_test)\n")
-#         #metrics template
-#         f.write("metrics = huble.sklearn.metrics.log_metrics(y_test, y_pred,'classification')\n")
-#         f.write("huble.sklearn.metrics.upload(metrics)\n")
-        
-
-#     #print(output_template)
-
