@@ -35,6 +35,22 @@ def return_function(node):
         return temp_ordinal_encode(node['data']['parameters'])
     elif node["data"]["value"] == "One Hot Encoding":
         return temp_one_hot_encode(node['data']['parameters'])
+    elif node["data"]["value"] == "Remove Mismatch Data":
+        return temp_remove_mismatch_data(node['data']['parameters'])
+    elif node["data"]["value"] == "Rename Columns":
+        return temp_rename_columns(node['data']['parameters'])
+    elif node["data"]["value"] == "Select Columns":
+        return temp_select_columns(node['data']['parameters'])
+    elif node["data"]["value"] == "Clean Column Names":
+        return temp_clean_column_names(node['data']['parameters'])
+    elif node["data"]["value"] == "Clip":
+        return temp_clip(node['data']['parameters'])
+    elif node["data"]["value"] == "Merge":
+        return temp_merge(node['data']['parameters'])
+    elif node["data"]["value"] == "Clean Data":
+        return temp_clean_data(node['data']['parameters'])
+    elif node["data"]["value"] == "Split":
+        return temp_split(node['data']['parameters'])
 
 def temp_remove_nan_values(params):
     subset=[]
@@ -222,3 +238,52 @@ def temp_one_hot_encode(params):
         "max_categories" : params['max_categories'],
     }
     return f"data = huble.sklearn.one_hot_encode(data=data, columns={columns}, parameters={parameters})"
+
+def temp_remove_mismatch_data(params):
+    parameters = {
+        "exceptions" : params['exceptions'],
+    }
+    return f"data = huble.sklearn.remove_mismatch_data(data=data, parameters={parameters})"
+
+def temp_rename_columns(params):
+    parameters = {
+        "mapper" : params['mapper'], 
+        "axis" : params['axis'],
+        "errors" : params['errors'],
+    }
+    return f"data = huble.sklearn.rename_columns(data=data, parameters={parameters})"
+
+def temp_select_columns(params):
+    parameters = {
+        "include" : params['include'], 
+        "exclude" : params['exclude'],
+    }
+    return f"data = huble.sklearn.select_columns(data=data, parameters={parameters})"
+
+def temp_clean_column_names(params):
+    return f"data = huble.sklearn.clean_column_names(data=data)"
+
+def temp_clip(params):
+    parameters = {
+        "lower" : params['lower'], 
+        "upper" : params['upper'],
+        "axis"  : params['axis'],
+    }
+    return f"data = huble.sklearn.clip(data=data, parameters={parameters})"
+
+def temp_merge(params):
+    parameters = {
+        "right" : params['right'], 
+        "how" : params['how'],
+        "on" : params['on'], 
+        "left_on" : params['left_on'],
+        "right_on" : params['right_on'], 
+        "sort" : params['sort'],
+    }
+    return f"data = huble.sklearn.merge(data=data, parameters={parameters})"
+
+def temp_clean_data(params):
+    return f"data = huble.sklearn.clean_data(data=data)"
+
+def temp_split(params):
+    return f"data = huble.sklearn.split(data=data)"
